Documentation
¶
Overview ¶
Package httpserver provides the HTTP/API server for RotomNG.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Address string
Listener net.Listener
UIPath string
UIFS *embed.FS
DevMode bool
MetricsHandler MetricsHandler
AuthMiddleware services.AuthMiddleware
APIHandler HTTPAPIHandler
StatsRegistrar services.StatsRegistrar
}
Config holds configuration for the HTTP server.
type HTTPAPIHandler ¶
type HTTPAPIHandler interface {
SetupAPIRoutes(apiGroup *gin.RouterGroup)
GetPrometheusEnabled() bool
GetConfig(ginContext *gin.Context)
ConfigReload(ginContext *gin.Context)
}
HTTPAPIHandler defines the interface for API route handlers.
type HTTPServer ¶
HTTPServer is a type alias for the generic web server.
func NewHTTPServer ¶
NewHTTPServer creates a new HTTPServer instance with app-specific route setup.
type MetricsHandler ¶
MetricsHandler defines the interface for providing a metrics HTTP handler.
Click to show internal directories.
Click to hide internal directories.